@@ -2,12 +2,13 @@
 from __future__ import print_function
 from functools import wraps
 
+import collections.abc
 import importlib
 import importlib.machinery
 import inspect
 import pickle
 
-from clu.constants.consts import λ, φ, BASEPATH, DEBUG, QUALIFIER, NoDefault
+from clu.constants.consts import λ, φ, BASEPATH, QUALIFIER, NoDefault
 from clu.exporting import (path_to_dotpath, determine_name,
                                             search_for_name,
                                             search_for_module)
@@ -200,11 +201,12 @@ def qualified_import(qualified):
     """
     if QUALIFIER not in qualified:
         raise ValueError(f"qualified name required (got {qualified})")
-    head, tail = dotpath_split(qualified)
-    module = importlib.import_module(tail)
-    imported = getattr(module, head)
-    if DEBUG:
-        print(f"Qualified Import: {qualified}")
+    try:
+        imported = importlib.import_module(qualified)
+    except ModuleNotFoundError:
+        head, tail = dotpath_split(qualified)
+        module = importlib.import_module(tail)
+        imported = getattr(module, head)
     return imported
 
 @export
@@ -221,8 +223,6 @@ def qualified_name(thing):
     """
     module_name, thing_name = qualified_name_tuple(thing)
     qualname = dotpath_join(module_name, thing_name)
-    if DEBUG:
-        print(f"Qualified Name: {qualname}")
     return qualname
 
 @export
@@ -247,7 +247,7 @@ def path_to_prefix(path, sep='-', end='-', relative_to=BASEPATH):
                              end=end)
 
 @export
-class rename(object):
+class rename(collections.abc.Callable):
     
     """ Function-rename decorator. Use like so:
         
