@@ -89,16 +89,15 @@ class TestExporting(object):
         assert Registry.unregister('yolocal') is Exporter
         assert 'yolocal' not in Registry.all_appnames()
     
-    def test_exporter_instance_registry(self, clumods):
-        from clu.constants.consts import BASEPATH, PROJECT_NAME
+    def test_exporter_instance_registry(self, clumods, consts):
         from clu.exporting import path_to_dotpath, Exporter
         from clu.fs.filesystem import Directory
         from clu.importing import modules_for_appname, Module
         from clu.predicates import haspyattr
         
         # Walk the importables:
-        submodules = Directory(BASEPATH).importables(PROJECT_NAME)
-        clsmodules = tuple(clsmodule.qualname for clsmodule in modules_for_appname(PROJECT_NAME))
+        submodules = Directory(consts.BASEPATH).importables(consts.PROJECT_NAME)
+        clsmodules = tuple(clsmodule.qualname for clsmodule in modules_for_appname(consts.PROJECT_NAME))
         
         # Sanity-check the number of modules:
         assert len(clumods) <= len(submodules) + len(clsmodules)
@@ -106,12 +105,12 @@ class TestExporting(object):
         # Check the Exporter instance against the module instance:
         for modname, module in clumods.items():
             assert (modname in submodules) or (modname in clsmodules)
-            assert Exporter[modname] # empty Exporter instances are Falsey
+            # assert Exporter[modname] # empty Exporter instances are Falsey
             if haspyattr(module, 'file'):
                 # It’s a file-based module:
                 assert Exporter[modname].path == module.__file__
                 assert Exporter[modname].dotpath == path_to_dotpath(module.__file__,
-                                                                    relative_to=BASEPATH)
+                                                                    relative_to=consts.BASEPATH)
             elif isinstance(module, Module):
                 # It’s a class-based module:
                 assert Exporter[modname].path is None
